#
# spec file for package python-linstor
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-linstor
Version:        1.12.0
Release:        1.7
Summary:        Python API for Linstor
License:        GPL-3.0-only
Group:          Productivity/Clustering/HA
URL:            https://github.com/LINBIT/linstor-api-py
Source:         https://pkg.linbit.com//downloads/linstor/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  protobuf-devel
Requires:       python-protobuf
%python_subpackages

%description
A Python API for Linstor.

%prep
%setup -q

%build
make %{?_smp_mflags} gensrc
%python_build

%install
#python setup.py install --single-version-externally-managed -O1 --root=%{buildroot} --record=INSTALLED_FILES
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#files -f INSTALLED_FILES
%files %{python_files}
%{python_sitelib}

%changelog
* Wed Jan 12 2022 nick wang <nwang@suse.com>
- bsc#1194567, update to 1.12.0
  * Added node evacuate command
  * Added external files support
  * Fix incorrect backup_delete parameter
  * Added Resource.clone()
  * Added snapshot-delete optional node_names list
  * Added rscgrp adjust method
  * Added node restore delete resources/snapshots option
  * fix exception with empty nodes in snapshot-definition
  * (Multi)Linstor() accepts now addition user-agent info
  * update linstor common-consts(bcache)
  * Relicensed as LGPLv3
  * Added option to re-use client in HighLvl-API
  * Added methods for shard-sp/exos support
  * API 1.12.0 compat
* Thu Dec 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Require python-protobuf instead of wronly used python_module: the
  latter would add dependencies to all python versions.
* Tue Jan 26 2021 nick wang <nwang@suse.com>
- bsc#1181397, update to 1.6.0
  * Added node_restore() method
  * Added addition_place_count params for auto_place
  * Node response object now has flags()
  * added SizeCalc.unit_to_str method
  * Added methods for error-report deletion
  * Node create case insensitive for types
* Tue Sep 22 2020 nick wang <nwang@suse.com>
- bsc#1176790, Update to 1.3.0
  * added snapshot_shipping_list method
  * setup.py: run make gensrc before python build
  * Code cleanup and fixed cyclic dependencies
* Mon Jun  1 2020 nick wang <nwang@suse.com>
- Update to 1.1.2
  * api: support storage-pool list argument
  * gitlab-ci: use xmlrunner and create junit reports
  * linstor-api: use new /view/snapshots
  * add gitlab ci
  * property filtering support
  * responses-node: add properties property
  * linstor-common: update to master
  * use newer drbdsetup.xml
  * use new device layer kind enum type
  * fix unset auto select filters on modify
  * rsc-grp-spawn: support external name
  * linstorapi: make api_version_smaller public
  * responses: Add DrbdResource layer data object and drbdconnections
  * resource: report first error not first message
  * add support for openflex on node and storage pool
  * node-create: add property dict as param
  * responses: add more storagepool docstrings
  * keyvaluestore: fix incorrect api access
  * use new const enum type
  * resource: allow to only spawn definitions
  * high-level API: expose query_max_volume_size in RG
  * decode: utf-8 has to be specified for py2
  * support gross-size in volume groups
  * fix json parsing in python3 < 3.6
  * doc: update sphinx doc
  * linstorapi: physical-device create add storage pool create support
  * linstorapi: remove swordfish support
  * resource: fix incompatibility with older linstor-servers
  * unittest: rework loading of unittests
  * use python3 per default
  * Added gross flag for vlmDfn (create and modify)
  * Added api call to rsc-grp qmvs
  * high-level API: add ResourceGroup object
  * linstorapi: added drbd_diskless and nvme_initiator to ResourceData
  * linstor-common: update
  * Added initial support for SPDK
  * responses: Add ApiCallResponse.__str__ method
  * resource: fix reply handling in activate() method
  * linstorapi: fix modify passphrase
  * Add methods to access storage_providers and resource_layers
  * linstorapi: add compatibility code for vd list API < 1.0.10
  * resource-api: correctly check for response errors
  * resource-api: add support for resource-groups
  * linstorapi: improve type comments
  * responses: add reports property to volumes
  * linstorapi-selectfilter: fix incorrect layer_list setting
  * linstorapi: slightly better error message on https connect fails
  * linstorapi: resource-dfn list, do not fail on empty list response
  * linstorapi: fix incorrect message on require_version method
  * linstorapi: add physica-storage API calls
  * physical-storage: allow multiple devices per node and storage pool
  * linstor-common: depend on TIE_BREAKER FLAG
  * linstorapi: add single resource connection query method
  * linstorapi: fix ssl error on python < 2.7.13
  * Unable to connect message grammar is incorrect
  * linstorapi: add parse_volume_size and LinstorArgumentError
  * linstorapi: add resource_group and volume_group methods
  * responses/ResourceDefinition: add resource_group_name property
  * linstorapi/rscdfn: rscdfn create allow linking of a specific rsc grp
  * update to latest linstor-common
  [...]
  - Version 0.9.9-1
  * linstorapi/snapshot_create: async_msg wasn't optional
  * linstorapi: add _raise versions of all *_list methods + update docstrings
  * linstorapi: HTTPS and auth support
  * netinterface: make linstorapi compatible with pre 1.0.7 API
  * Allow node to set active stlt conn on netIf crt or mod
  * Add api-function for listing net interfaces
  * responses: fix broken ApiCallResponse.is_error(code)
  * config: fix py2/py3 safeconfigparser import
  * code cleanup
  * responses: fix incorrect apicallresponse v0 output
  * apicallresponse: implement __eq__ and __hash__
  * responses-storagepool: add reports field
  * resource: Check for non existend resource on _linstor_name access
  * resource: only read the NON diskless storage pool name
  * resource: add linstor error messages to exception
  [...]
* Tue May 28 2019 nwang@suse.com
- Update to 0.9.5
  - linstor-client/python-linstor 0.9.5
  * Fixed: combined query filters are incorrectly concatenated
  * Fixed: keep-alive (interactive) mode
  * High-Level API: Resource class now works with external names
  - linstor-client/python-linstor 0.9.4
  * API/Client now uses REST-API
  * Added curl command output mode
  * Updated to latest drbd options
  * DRBDManage migrate generator now uses resource transactions
  * Package support for RHEL8
  - linstor-client/python-linstor 0.9.3
  * Support nvme layers
* Tue Apr  9 2019 nwang@suse.com
- Update to upstream release 0.9.2
  * Create node IP address will be resolved if not given
  * Removed all name checks, they are checked by the controller anyway
  * Resource definition peer-slots can now be modified
  * DRBD-handlers can now be specified for controller and resource-definition
* Thu Apr  4 2019 nwang@suse.com
- Update to upstream release 0.9.1
  * Resource: create volume definitions before actions
  * Add linstor.Config class
  * Add high-level API
  * Add upload-doc target
* Wed Oct 31 2018 nwang@suse.com
- Update to upstream release 0.7.0 (linstor-client)
  * Added Proxy configuration commands
  * Synchronous auto-place and storage-pool create commands
  * Resource connection commands (list, props, drbd options)
  * Improved table rendering
  * error list --since allows now hours to be specified
* Fri Oct 19 2018 Jan Engelhardt <jengelh@inai.de>
- Remove duplicated word (API includes "interface").
* Thu Sep 27 2018 nwang@suse.com
- bsc#1095668. First version, 0.6.2.
